timeintervaltools.all_intervals_are_contiguous
==============================================

.. autofunction:: abjad.tools.timeintervaltools.all_intervals_are_contiguous.all_intervals_are_contiguous
